--[[

$Revision: 102 $

(C) Copyright 2009 Bethink (bethink at naef dot com)
See LICENSE.txt for license terms.

]]


----------------------------------------------------------------------
-- Initialization

local L = LibStub("AceLocale-3.0"):GetLocale("BossNotes")


----------------------------------------------------------------------
-- Encounters

BOSS_NOTES_ENCOUNTERS = {
	-- Wrath of the Lich King Raid
	{
		instanceSetId = "WotlkRaid",
		default = true,
		instances = {
			{
				instanceId = "Ulduar",
				npcIds = {
					34197, 34133, 33715, 33354, 33431, 34085, 33430, 33528,
					34190, 34198, 33526, 32882, 34199, 34086, 33525, 33355,
					33527, 34267, 33768, 34196, 32872, 33699, 33722, 34137,
					34134, 34135, 34273, 34271, 34269 
				},
				encounters = {
					{
						-- Flame Leviathan
						encounterId = 33113
					},
					{
						-- Razorscale
						encounterId = 33186,
						npcIds = { 33186, 33388, 33846, 33453 }
					},
					{
						-- Ignis the Furnace Master
						encounterId = 33118,
						npcIds = { 33118, 33221 }
					},
					{
						-- XT-002 Deconstructor
						encounterId = 33293,
						npcIds = { 33293, 33329, 33346, 33344 }
					},
					{
						-- Assembly of Iron
						encounterId = 32867,
						npcIds = { 32867, 32927, 32857 }
					},
					{
						-- Kologarn
						encounterId = 32930
					},
					{
						-- Auriaya
						encounterId = 33515,
						npcIds = { 33515, 34035, 34014 }
					},
					{
						-- Hodir
						encounterId = 32845
					},
					{
						-- Thorim
						encounterId = 32865,
						npcIds = {
							32865, 32873, 32908, 32885, 32886, 32957, 33110, 32876,
							32904, 32878, 32877, 33125, 32874, 33196
						},
					},
					{
						-- Freya
						encounterId = 32906,
						npcIds = {
							32906, 32915, 32913, 32914, 33203, 33202, 32918, 33228,
							33088, 32916, 32919, 33050
						}
					},
					{
						-- Mimiron
						encounterId = 33350
					},
					{
						-- General Vezax
						encounterId = 33271
					},
					{
						-- Yogg-Saron
						encounterId = 33288
					},
					--[[
					{
						-- Algalon the Observer
						encounterId = 0 -- TODO: check
					},
					]]
				}
			},
			{
				instanceId = "Naxxramas",
				npcIds = {
					16018, 15975, 15978, 16156, 16146, 16145, 16163, 29818,
					15974, 16024, 16236, 16036, 16244, 16385, 16021, 16027,
					16020, 30083, 16297, 15981, 15980, 16165, 16017, 16034,
					16037, 16375, 16164, 16193, 16029, 30071, 16025, 16168,
					16022, 15979, 16194, 16215, 16216, 15976
				},
				encounters = {
					{
						-- Anub'rekhan
						encounterId = 15956,
						npcIds = { 15956, 16573 }
					},
					{
						-- Grand Widow Faerlina
						encounterId = 15953,
						npcIds = { 15953, 16505, 16506 }
					},
					{
						-- Maexxna
						encounterId = 15952,
					},
					{
						-- Noth the Plaguebringer
						encounterId = 15954,
						npcIds = { 15954, 16983, 16984 }
					},
					{
						-- Heigan the Unclean
						encounterId = 15936
					},
					{
						-- Loatheb
						encounterId = 16011,
						npcIds = { 16011, 16286 }
					},
					{
						-- Instructor Razuvious
						encounterId = 16061
					},
					{
						-- Gothik the Harvester
						encounterId = 16060,
						npcIds = {
							16060, 16148, 16149, 16150, 16127, 16125, 16126,
							16124
						}
					},
					{
						-- The Four Horsemen
						encounterId = 16063,
						npcIds = { 30549, 16065, 16063, 16064 }
					},
					{
						-- Patchwerk
						encounterId = 16028
					},
					{
						-- Grobbulus
						encounterId = 15931,
						npcIds = { 15931, 16363 }
					},
					{
						-- Gluth
						encounterId = 15932
					},
					{
						-- Thaddius
						encounterId = 15928,
						npcIds = {15928, 15930, 15929 }
					},
					{
						-- Sapphiron
						encounterId = 15989,
						npcIds = { 15989, 16474 }
					},
					{
						-- Kel'Thuzad
						encounterId = 15990,
						npcIds = { 15990, 16441, 16129, 16428 }
					}
				}
			},
			{
				instanceId = "TheEyeOfEternity",
				encounters = {
					{
						-- Malygos
						encounterId = 28859,
						npcIds = { 28859, 30245, 30249, 30592, 30084 }
					}
				}
			},
			{
				instanceId = "TheObsidianSanctum",
				npcIds = { 30681, 30680, 30682, 30453 },
				encounters = {
					{
						-- Sartharion
						encounterId = 28860,
						npcIds = { 28860, 30451, 30452, 30449, 30641, 31214 }
					}
				}
			},
			{
				instanceId = "VaultOfArchavon",
				npcIds = { 32353, 34015 },
				encounters = {
					{
						-- Archavon the Stone Watcher
						encounterId = 31125
					},
					{
						-- Emalon the Storm Watcher
						encounterId = 33993,
						npcIds = { 33993, 33998, 34049 },
					}
				}
			}
		}
	},
	
	-- Wrath of the Lich King Dungeons
	{
		instanceSetId = "WotlkDungeon",
		default = true,
		instances = {
			{
				instanceId = "HallsOfLightning",
				npcIds = {
					28583, 28579, 28578, 28580, 28585, 28835, 28920,
					28582, 28836, 28837, 28581, 28826, 28547, 28961,
					28965, 28838, 28584
				},
				encounters = {
					{
						-- General Bjarngrim
						encounterId = 28586,
						npcIds = { 28586, 29240 }
					},
					{
						-- Volkhan
						encounterId = 28587,
						npcIds = { 28587, 28695 }
					},
					{
						-- Ionar
						encounterId = 28546,
						npcIds = { 28546, 28926 }
					},
					{
						-- Loken
						encounterId = 28923
					}
				}
			},
			{
				instanceId = "TheCullingOfStratholme",
				npcIds = {
					27731, 28201, 27734, 28200, 28249, 27729, 27742, 27744,
					28341, 27743, 28340, 27732
				},
				encounters = {
					{
						-- Meathook
						encounterId = 26529
					},
					{
						-- Salramm the Fleshcrafter
						encounterId = 26530
					},
					{
						-- Chrono-Lord Epoch
						encounterId = 26532
					},
					{
						-- Mal'Ganis
						encounterId = 26533
					},
					{
						-- Infinite Corruptor
						encounterId = 32273
					}
				}
			},
			{
				instanceId = "TheOculus",
				encounters = {
					{
						-- Drakos The Interrogator
						encounterId = 27654
					},
					{
						-- Varos Cloudstrider
						encounterId = 27447
					},
					{
						-- Mage-Lord Urom
						encounterId = 27655
					},
					{
						-- Ley-Guardian Eregos
						encounterId = 27656
					}
				}
			},
			{
				instanceId = "UtgardePinnacle",
				npcIds = {
					26672, 26550, 26553, 26554, 26555, 26696, 26694, 26670,
					28368, 26669
				},
				encounters = {
					{
						-- Svala Sorrowgrave
						encounterId = 26668,
						npcIds = { 26668, 27281 }
					},
					{
						-- Gortok Palehoof
						encounterId = 26687,
						npcIds = {26687, 26686, 26683, 26685, 26684 }
					},
					{
						-- Skdadi the Ruthless
						encounterId = 26693,
						npcIds = { 26693, 26692, 26690, 26691 }
					},
					{
						-- King Ymiron
						encounterId = 26861,
						npcIds = { 26861, 27339 }
					}
				}
			},
			{
				instanceId = "HallsOfStone",
				npcIds = {
					27966, 27962, 27969, 27964, 27965, 27963, 27960, 27961,
					28384, 27972, 27970, 27971
				},
				encounters = {
					{
						-- Maiden of Grief
						encounterId = 27975
					},
					{
						-- Krystallus
						encounterId = 27977
					},
					{
						-- Tribunal of Ages
						encounterId = 27983,
						npcIds = { 28235, 27983, 27984, 27985 }
					},
					{
						-- Sjonnir The Ironshaper
						encounterId = 27978,
						npcIds = { 27978, 27982, 27979 }
					}
				}
			},
			{
				instanceId = "Gundrak",
				npcIds = {
					29836, 29829, 29822, 29820, 29832, 29874, 29819, 29826,
					29982, 29830, 29920, 29774, 29768
				},
				encounters = {
					{
						-- Slad'ran
						encounterId = 29304,
						npcIds = { 29304, 29713, 29680, 29742 }
					},
					{
						-- Drakkari Colossus
						encounterId = 29307,
						npcIds = { 29307, 29573 }
					},
					{
						-- Moorabi
						encounterId = 29305
					},
					{
						-- Gal'darah
						encounterId = 29306
					},
					{
						-- Eck the Ferocious
						encounterId = 29932
					}
				}
			},
			{
				instanceId = "TheVioletHold",
				npcIds = {
					30918, 30666, 30661, 30961, 30664, 30668, 31079, 30667,
					32191, 30837, 30660, 30892, 30695, 30893
				},
				encounters = {
					{
						-- Erekem
						encounterId = 29315,
						npcIds = { 29315, 29395 }
					},
					{
						-- Moragg
						encounterId = 29316
					},
					{
						-- Ichoron
						encounterId = 29313,
						npcIds = { 29313, 29321 }
					},
					{
						-- Xevozz
						encounterId = 29266
					},
					{
						-- Lavanthor
						encounterId = 29312
					},
					{
						-- Zuramat The Obliterator
						encounterId = 29314
					},
					{
						-- Cayanigosa
						encounterId = 31134
					}
				}
			},
			{
				instanceId = "DrakTharonKeep",
				npcIds = {
					26625, 26620, 26641, 26639, 27431, 27871, 26621, 26638,
					26830, 26637, 26636, 26635, 26623, 26626, 26624
				},
				encounters = {
					{
						-- Trollgore
						encounterId = 26630
					},
					{
						-- Novos The Summonor
						encounterId = 26631,
						npcIds = { 26631, 26627, 27600 },
					},
					{
						-- King Dred
						encounterId = 27483,
						npcIds = { 27483, 26628 }
					},
					{
						-- The Prophet Tharon'ja
						encounterId = 26632
					}
				}
			},
			{
				instanceId = "AhnKahetTheOldKingdom",
				encounters = {
					{
						-- Elder Nadox
						encounterId = 29309
					},
					{
						-- Prince Taldaram
						encounterId = 29308
					},
					{
						-- Jedoga Shadowseeker
						encounterId = 29310
					},
					{
						-- Herald Volazj
						encounterId = 29311
					},
					{
						-- Amanitar
						encounterId = 30258
					}
				}
			},
			{
				instanceId = "AzjolNerub",
				encounters = {
					{
						-- Krik'thir the Gatewatcher
						encounterId = 28684
					},
					{
						-- Hadronox
						encounterId = 28921
					},
					{
						-- Anub'arak
						encounterId = 29120
					}
				}
			},
			{
				instanceId = "TheNexus",
				encounters = {
					{
						-- Grand Magus Telestra
						encounterId = 26731,
						npcIds = { 26731, 29928, 26929, 26930 }
					},
					{
						-- Anomalus
						encounterId = 26763
					},
					{
						-- Ormorok The Tree-Shaper
						encounterId = 26794
					},
					{
						-- Keristrsza
						encounterId = 27723
					},
					{
						-- Commander Stoutbeard
						encounterId = 26795
					},
					{
						-- Commander Kolurg
						encounterId = 26798
					}
				}
			},
			{
				instanceId = "UtgardeKeep",
				npcIds = {
					24069, 24079, 24071, 23961, 24078, 24085, 23960, 28410,
					23956, 24080, 24082, 24849, 29735, 32246, 24084
				},
				encounters = {
					{
						-- Prince Keleseth
						encounterId = 23953,
						npcIds = { 23953, 23970 },
					},
					{
						-- Skarvald & Dalronn
						encounterId = 24200,
						npcIds = { 24200, 24201 }
					},
					{
						-- Ingvar the Punderer
						encounterId = 23954
					}
				}
			}
		}
	},
	
	-- The Burning Crusade Raid
	{
		instanceSetId = "TbcRaid",
		default = false,
		instances = {
			{
				instanceId = "SunwellPlateau",
				encounters = {
					{
						-- Kalecgos
						encounterId = 24850,
						npcIds = { 24850, 24892 }
					},
					{
						-- Brutallus
						encounterId = 24882
					},
					{
						-- Felmyst
						encounterId = 25038
					},
					{
						-- Eredar Twins
						encounterId = 25164,
						npcIds = { 25166, 25164 }
					},
					{
						-- M'uru
						encounterId = 25741,
						npcIds = { 25741, 25840 }
					},
					{
						-- Kil'jaeden
						encounterId = 25315
					}
				}
			},
			{
				instanceId = "BlackTemple",
				encounters = {
					{
						-- High Warlord Naj'entus
						encounterId = 22887
					},
					{
						-- Supremus
						encounterId = 22898
					},
					{
						-- Shade of Akama
						encounterId = 22841
					},
					{
						-- Teron Gorefiend
						encounterId = 22871
					},
					{
						-- Gurtogg Bloodboil
						encounterId = 22948
					},
					{
						-- Reqliquary of Souls
						encounterId = 23418,
						npcIds = { 23418, 23419, 23420 }
					},
					{
						-- Mother Shahraz
						encounterId = 22947
					},
					{
						-- The Illidari Council
						encounterId = 22949,
						npcIds = { 22949, 22950, 22951, 22952 }
					},
					{
						-- Illidan Stormrage
						encounterId = 22917
					}
				}
			},
			{
				instanceId = "HyjalSummit",
				encounters = {
					{
						-- Rage Winterchill
						encounterId = 17767
					},
					{
						-- Anetheron
						encounterId = 17808
					},
					{
						-- Kaz'rogal
						encounterId = 17888
					},
					{
						-- Azgalor
						encounterId = 17842
					},
					{
						-- Archimonde
						encounterId = 17968
					}
				}
			},
			{
				instanceId = "ZulAman",
				encounters = {
					{
						-- Akil'zon
						encounterId = 23574
					},
					{
						-- Nalorakk
						encounterId = 23576
					},
					{
						-- Jan'alai
						encounterId = 23578
					},
					{
						-- Halazzi
						encounterId = 23577
					},
					{
						-- Hex Lord Malacrass
						encounterId = 24239
					},
					{
						-- Zul'jin
						encounterId = 23863
					}
				}
			},
			{
				instanceId = "SerpentshrineCavern",
				encounters = {
					{
						-- Hydross the Unstable
						encounterId = 21216
					},
					{
						-- The Lurker Below
						encounterId = 21217
					},
					{
						-- Leotheras the Blind
						encounterId = 21215
					},
					{
						-- Fathom-Lord Karathress
						encounterId = 21214
					},
					{
						-- Morogrim Tidewalker
						encounterId = 21213
					},
					{
						-- Lady Vashj
						encounterId = 21212
					}
				}
			},
			{
				instanceId = "TheEye",
				encounters = {
					{
						-- Void Reaver
						encounterId = 19516
					},
					{
						-- A'lar
						encounterId = 19514
					},
					{
						-- High Astromancer Solarian
						encounterId = 18805
					},
					{
						-- Kael'thas Sunstrider
						encounterId = 19622
					}
				}
			},
			{
				instanceId = "MagtheridonsLair",
				encounters = {
					{
						-- Magtheridon
						encounterId = 17257
					}
				}
			},
			{
				instanceId = "GruulsLair",
				encounters = {
					{
						-- High King Maulgar
						encounterId = 18831,
						npcIds = { 18831, 18836, 18835, 18832, 18834 }
					},
					{
						-- Gruul the Dragonkiller
						encounterId = 19044
					}
				}
			},
			{
				instanceId = "Karazhan",
				encounters = {
					{
						-- Hyakiss the Lurker
						encounterId = 16179
					},
					{
						-- Rokad the Ravager
						encounterId = 16181
					},
					{
						-- Shadikith the Glider
						encounterId = 16180
					},
					{
						-- Atumen the Huntsman
						encounterId = 15550,
						npcIds = { 15550, 16151 }
					},
					{
						-- Moroes
						encounterId = 15687
					},
					{
						-- Maiden of Virtue
						encounterId = 16457
					},
					{
						-- Romulo and Julianne
						encounterId = 17533,
						npcIds = { 17533, 17534 }
					},
					{
						-- The Big Bad Wolf
						encounterId = 17521
					},
					{
						-- Wizard of Oz
						encounterId = 18168,
						npcIds = { 18168,  17535, 17546, 17543, 17547, 17548 }
					},
					{
						-- Nightbane
						encounterId = 17225
					},
					{
						-- The Curator
						encounterId = 15691
					},
					{
						-- Terestian Illhoof
						encounterId = 15688
					},
					{
						-- Shade of Aran
						encounterId = 16524
					},
					{
						-- Netherspite
						encounterId = 15689
					},
					{
						-- Chess Event
						encounterId = 16816
					},
					{
						-- Prince Malchezaar
						encounterId = 15690
					}
				}
			}
		}
	},
	
	-- The Burning Crusade Dungeon
	{
		instanceSetId = "TbcDungeon",
		default = false,
		instances = {
			{
				-- Magisters' Terrace
				instanceId = "MagistersTerrace",
				encounters = {
					{
						-- Selin Fireheart
						encounterId = 24723
					},
					{
						-- Vexallus
						encounterId = 24744
					},
					{
						-- Priestess Delrissa
						encounterId = 24560
					},
					{
						-- Kael'thas Sunstrider
						encounterId = 24664
					}
				}
			},
			{
				-- Shadow Labyrinth
				instanceId = "ShadowLabyrinth",
				encounters = {
					{
						-- Ambassador Hellmaw
						encounterId = 18731
					},
					{
						-- Blackheart the Inciter
						encounterId = 18667
					},
					{
						-- Grandmaster Vorpil
						encounterId = 18732
					},
					{
						-- Murmur
						encounterId = 18708
					}
				}
			},
			{
				-- The Arcatraz
				instanceId = "TheArcatraz",
				encounters = {
					{
						-- Zereketh the Unbound
						encounterId = 20870
					},
					{
						-- Dalliah the Doomsayer
						encounterId = 20885
					},
					{
						-- Wrath-Scryer Soccothrates
						encounterId = 20886
					},
					{
						-- Harbinger Skyriss
						encounterId = 20912
					}
				}
			},
			{
				-- The Black Morass
				instanceId = "TheBlackMorass",
				encounters = {
					{
						-- Chrono Lord Deja
						encounterId = 17879
					},
					{
						-- Temporus
						encounterId = 17880
					},
					{
						-- Aeonus
						encounterId = 17881
					}
				}
			},
			{
				-- The Botanica
				instanceId = "TheBotanica",
				encounters = {
					{
						-- Commander Sarannis
						encounterId = 17976
					},
					{
						-- High Botanist Freywinn
						encounterId = 17975
					},
					{
						-- Thorngrin the Tender
						encounterId = 17978
					},
					{
						-- Laj
						encounterId = 17980
					},
					{
						-- Warp Splinter
						encounterId = 17977
					}
				}
			},
			{
				-- The Mechanar
				instanceId = "TheMechanar",
				encounters = {
					{
						-- Gatewatcher Gyro-Kill
						encounterId = 19218
					},
					{
						-- Gatewatcher Iron-Hand
						encounterId = 19710
					},
					{
						-- Mechano-Lord Capacitus
						encounterId = 19219
					},
					{
						-- Nethermancer Sepethrea
						encounterId = 19221
					},
					{
						-- Pathaleon the Calculator
						encounterId = 19220
					}
				}
			},
			{
				-- The Shattered Halls
				instanceId = "TheShatteredHalls",
				encounters = {
					{
						-- Grand Warlock Nethekurse
						encounterId = 16807
					},
					{
						-- Blood Guard Porung
						encounterId = 20923
					},
					{
						-- Warbringer O'mrogg
						encounterId = 16809
					},
					{
						-- Warchief Kargath Bladefist
						encounterId = 16808
					}
				}
			},
			{
				-- The Steamvault
				instanceId = "TheSteamvault",
				encounters = {
					{
						-- Hydromancer Thespia
						encounterId = 17797
					},
					{
						-- Mekgineer Steamrigger
						encounterId = 17796
					},
					{
						-- Warlord Kalithresh
						encounterId = 17798
					}
				}
			},
			{
				-- Sethekk Halls
				instanceId = "SethekkHalls",
				encounters = {
					{
						-- Darkweaver Syth
						encounterId = 18472
					},
					{
						-- Talon King Ikiss
						encounterId = 18473
					}
				}
			},
			{
				-- Old Hillsbrad Foothills
				instanceId = "OldHillsbradFoothills",
				encounters = {
					{
						-- Lieutenant Drake
						encounterId = 17848
					},
					{
						-- Captain Skarloc
						encounterId = 17862
					},
					{
						-- Epoch Hunter
						encounterId = 18096
					}
				}
			},
			{
				-- Auchenai Crypts
				instanceId = "AuchenaiCrypts",
				encounters = {
					{
						-- Shirrak the Dead Watcher
						encounterId = 18371
					},
					{
						-- Exarch Maladaar
						encounterId = 18373
					}
				}
			},
			{
				-- Mana-Tombs
				instanceId = "ManaTombs",
				encounters = {
					{
						-- Pandemonius
						encounterId = 18341
					},
					{
						-- Tavarok
						encounterId = 18343
					},
					{
						-- Nexus-Prince Shaffar
						encounterId = 18344
					},
					{
						-- Yor
						encounterId = 22930
					}
				}
			},
			{
				-- The Underbog
				instanceId = "TheUnderbog",
				encounters = {
					{
						-- Hungarfen
						encounterId = 17770
					},
					{
						-- Ghaz'an
						encounterId = 18105
					},
					{
						-- Swamplord Musel'ek
						encounterId = 17826
					},
					{
						-- The Black Stalker
						encounterId = 17882
					}
				}
			},
			{
				-- The Slave Pens
				instanceId = "TheSlavePens",
				encounters = {
					{
						-- Mennu the Betrayer
						encounterId = 17941
					},
					{
						-- Rokmar the Crackler
						encounterId = 17991
					},
					{
						-- Quagmirran
						encounterId = 17942
					}
				}
			},
			{
				-- The Blood Furnace
				instanceId = "TheBloodFurnace",
				encounters = {
					{
						-- The Maker
						encounterId = 17381
					},
					{
						-- Broggok
						encounterId = 17380
					},
					{
						-- Keli'dan the Breaker
						encounterId = 17377
					}
				}
			},
			{
				-- Hellfire Ramparts
				instanceId = "HelfireRamparts",
				encounters = {
					{
						-- Watchkeeper Gargolmar
						encounterId = 17306
					},
					{
						-- Omor the Unscarred
						encounterId = 17308
					},
					{
						-- Vazruden
						encounterId = 17537,
						npcIds = { 17537, 17536 }
					}
				}
			}
		}
	},
	
	-- Classic Raid
	{
		instanceSetId = "ClassicRaid",
		default = false,
		instances = {
			{
				instanceId = "TempleOfAhnQiraj",
				npcIds = {
					15264, 15311, 15537, 15725, 15726, 15262, 15312, 15247,
					15252, 15249, 15246, 15250, 15233, 15240, 15229, 15230
				},
				encounters = {
					{
						-- The Prophet Skeram
						encounterId = 15263
					},
					{
						-- Bug Trio
						encounterId = 15511,
						npcIds = { 15543, 15544, 15511, 15933, 15621 }
 					},
					{
						-- Battleguard Sartura
						encounterId = 15516,
						npcIds = { 15516, 15984 }
					},
					{
						-- Fankriss the Unyielding
						encounterId = 15510
					},
					{
						-- Viscidus
						encounterId = 15299
					},
					{
						-- Princess Huhuran
						encounterId = 15509
					},
					{
						-- Twin Emperors
						encounterId = 15275,
						npcIds = { 15276, 15275, 15316, 15317 }
					},
					{
						-- Ouro
						encounterId = 15517,
						npcIds = { 15517, 15712 }
					},
					{
						-- C'Thun
						encounterId = 15727,
						npcIds = { 15589, 15727, 15726, 15802, 15728, 15334 }
					}
				}
			},
			{
				instanceId = "BlackwingLair",
				encounters = {
					{
						-- Razorgore the Untamed
						encounterId = 12435
					},
					{
						-- Vaelastrasz the Corrupt
						encounterId = 13020
					},
					{
						-- Broodlord Lashlayer
						encounterId = 12017
					},
					{
						-- Firemaw
						encounterId = 11983
					},
					{
						-- Ebonroc
						encounterId = 14601
					},
					{
						-- Flamegor
						encounterId = 11981
					},
					{
						-- Chromaggus
						encounterId = 14020
					},
					{
						-- Nefarian
						encounterId = 11583
					}
				}
			},
			{
				instanceId = "MoltenCore",
				npcIds = {
					11673, 11671, 11668, 11666, 11667, 11669, 12076, 12100,
					12265, 12101, 11659, 11658
				},
				encounters = {
					{
						-- Lucifron
						encounterId = 12118,
						npcIds = { 12118, 12119 },
					},
					{
						-- Magmadar
						encounterId = 11982
					},
					{
						-- Gehenas
						encounterId = 12259,
						npcIds = { 12259, 11661 },
					},
					{
						-- Garr
						encounterId = 12057,
						npcIds = { 12057, 12099 },
					},
					{
						--Shazzrah
						encounterId = 12264,
					},
					{
						-- Baron Geddon
						encounterId = 12056
					},
					{
						-- Golemagg the Incinerator
						encounterId = 11988,
						npcIds = { 11988, 11672 },
					},
					{
						-- Sulfuron Harbinger
						encounterId = 12098,
						npcIds = { 12098, 11662 },
					},
					{
						-- Majordomo Executus
						encounterId = 12018,
						npcIds = { 12018, 11663, 11664 },
					},
					{
						-- Ragnaros
						encounterId = 11502
					}
				}
			},
			{
				instanceId = "OnyxiasLair",
				encounters = {
					{
						-- Onyxia
						encounterId = 10184
					}
				}
			},
			{
				instanceId = "RuinsOfAhnQiraj",
				encounters = {
					{
						-- Kurinnaxx
						encounterId = 15348
					},
					{
						-- General Rajaxx
						encounterId = 15341
					},
					{
						-- Moam
						encounterId = 15340
					},
					{
						-- Buru the Gorger
						encounterId = 15370
					},
					{
						-- Ayamiss the Hunter
						encounterId = 15369
					},
					{
						-- Ossirian the Unscarred
						encounterId = 15339
					}
				}
			},
			{
				instanceId = "ZulGurub",
				encounters = {
					{
						-- High Priestess Jeklik
						encounterId = 14517
					},
					{
						-- High Priest Venoxis
						encounterId = 14507
					},
					{
						-- High Priestess Mar'li
						encounterId = 14510
					},
					{
						-- Bloodlord Mandokir
						encounterId = 11382,
						npcIds = { 11382, 14988 }
					},
					{
						-- Edge of Madness
						encounterId = 15082,
						npcIds = { 15082, 15083, 15084, 15085 }
					},
					{
						-- Gahz'ranka
						encounterId = 15114
					},
					{
						-- High Priest Thekal
						encounterId = 14509
					},
					{
						-- High Priestess Arlokk
						encounterId = 14515
					},
					{
						-- Jin'do the Hexxer
						encounterId = 11380
					},
					{
						-- Hakkar the Soulflayer
						encounterId = 14834
					}
				}
			}
		}
	},
	
	-- Classic Dungeon
	{
		instanceSetId = "ClassicDungeon",
		default = false,
		instances = {
			{
				-- Blackrock Spire
				instanceId = "BlackrockSpire",
				encounters = {
					{
						-- Highlord Omokk
						encounterId = 9196
					},
					{
						-- Shadow Hunter Vosh'Gaijn
						encounterId = 9236
					},
					{
						-- War Master Voone
						encounterId = 9237
					},
					{
						-- Mor Grayhoof
						encounterId = 16080
					},
					{
						-- Mother Smolderweb
						encounterId = 10596
					},
					{
						-- Urok Doomhowl
						encounterId = 10584
					},
					{
						-- Quartermaster Zigris
						encounterId = 9736
					},
					{
						-- Halycon
						encounterId = 10220,
						npcIds = { 10220, 10268 }
					},
					{
						-- Overlord Wyrmthalak
						encounterId = 9568
					},
					{
						-- Pyroguard Emberseer
						encounterId = 9816
					},
					{
						-- Solakar Flamewreath
						encounterId = 10264
					},
					{
						-- Goraluk Anvilcrack
						encounterId = 10899
					},
					{
						-- Warchief Rend Blackhand
						encounterId = 10429,
						npcIds = { 10429, 10339 }
					},
					{
						-- The Beast
						encounterId = 10430
					},
					{
						-- Lord Valthalak
						encounterId = 16042
					},
					{
						-- General Drakkisath
						encounterId = 10363
					}
				}
			},
			{
				-- Dire Maul
				instanceId = "DireMaul",
				encounters = {
					{
						-- Pusillin
						encounterId = 14354
					},
					{
						-- Zevrim Thornhoof
						encounterId = 11490
					},
					{
						-- Hydrospawn
						encounterId = 13280
					},
					{
						-- Lethendris
						encounterId = 14327
					},
					{
						-- Alzzin the Wildshaper
						encounterId = 11492
					},
					{
						-- Isalien
						encounterId = 16097
					},
					{
						-- Tendris Warpwood
						encounterId = 11489
					},
					{
						-- Magister Kalendris
						encounterId = 11487
					},
					{
						-- Illyanna Ravenoak
						encounterId = 11488
					},
					{
						-- Immol'thar
						encounterId = 11496
					},
					{
						-- Prince Tortheldrin
						encounterId = 11486
					},
					{
						-- Guard Mol'dar
						encounterId = 14326
					},
					{
						-- Stomper Kreeg
						encounterId = 14322
					},
					{
						-- Guard Fengus
						encounterId = 14321
					},
					{
						-- Guard Slip'kik
						encounterId = 14323
					},
					{
						-- Captain Kromcrush
						encounterId = 14325
					},
					{
						-- King Gordok
						encounterId = 11501,
						npcIds = { 11501, 14324 }
					}
				}
			},
			{
				-- Scholomance
				instanceId = "Scholomance",
				encounters = {
					{
						-- Blood Steward of Kirtonos
						encounterId = 14861
					},
					{
						-- Kirtonos the Herald
						encounterId = 10506
					},
					{
						-- Jandice Barov
						encounterId = 10503
					},
					{
						-- Rattlegore
						encounterId = 11662
					},
					{
						-- Marduk Blackpool
						encounterId = 10433
					},
					{
						-- Vectus
						encounterId = 10432
					},
					{
						-- Ras Frostwhisper
						encounterId = 10508
					},
					{
						-- Kormok
						encounterId = 16118
					},
					{
						-- Lady Illucia Barov
						encounterId = 10502
					},
					{
						-- Lord Alexei Barov
						encounterId = 10504
					},
					{
						-- The Ravenian
						encounterId = 10507
					},
					{
						-- Lorekeeper Polkelt
						encounterId = 10901
					},
					{
						-- Doctor Theolen Krastinov
						encounterId = 11261
					},
					{
						-- Instructor Malicia
						encounterId = 10505
					},
					{
						-- Darkmaster Gandling
						encounterId = 1853
					}
				}
			},
			{
				-- Stratholme
				instanceId = "Stratholme",
				encounters = {
					{
						-- Stratholme Courier
						encounterId = 11082
					},
					{
						-- Fras Siabi
						encounterId = 11058
					},
					{
						-- Hearthsinger Forresten
						encounterId = 10558
					},
					{
						-- The Unforgiven
						encounterId = 10516
					},
					{
						-- Postmaster Malown
						encounterId = 11143
					},
					{
						-- Timmy the Cruel
						encounterId = 10808
					},
					{
						-- Malor the Zealous
						encounterId = 11032
					},
					{
						-- Cannon Master Willey
						encounterId = 10997
					},
					{
						-- Crimson Hammersmith
						encounterId = 11120
					},
					{
						-- Archivist Galford
						encounterId = 10811
					},
					{
						-- Grand Crusader Dathrohan
						encounterId = 10812,
						npcIds = { 10812, 10813 }
					},
					{
						-- Jarien & Sothos
						encounterId = 16101,
						npcIds = { 16101, 16102 }
					},
					{
						-- Nerub'enkan
						encounterId = 10437
					},
					{
						-- Baroness Anastari
						encounterId = 10436
					},
					{
						-- Black Guard Swordsmith
						encounterId = 11121
					},
					{
						-- Maleki the Pallid
						encounterId = 10438
					},
					{
						-- Magistrate Barthilas
						encounterId = 10435
					},
					{
						-- Ramstein the Gorger
						encounterId = 10439
					},
					{
						-- Baron Rivendare
						encounterId = 10440
					}
				}
			},
			{
				-- Blackrock Depths
				instanceId = "BlackrockDepths",
				encounters = {
					{
						-- High Interrogator Gerstahn
						encounterId = 9018
					},
					{
						-- Houndmaster Grebmar
						encounterId = 9319
					},
					{
						-- Lord Roccor
						encounterId = 9025
					},
					{
						-- Ring of Law
						encounterId = 10096,
						npcIds =  { 10096, 9027, 9028, 9029, 9030, 9031, 9032 }
					},
					{
						-- Pyromancer Loregrain
						encounterId = 9024
					},
					{
						-- Warder Stilgiss
						encounterId = 9041,
						npcIds = { 9041, 9042 }
					},
					{
						-- Watchman Doomgrip
						encounterId = 9476
					},
					{
						-- Fineous Darkvire
						encounterId = 9056
					},
					{
						-- Lord Incendius
						encounterId = 9017
					},
					{
						-- Bael'Gar
						encounterId = 9016
					},
					{
						-- General Angerforge
						encounterId = 9033
					},
					{
						-- Golem Lord Argelmach
						encounterId = 8983
					},
					{
						-- Hurley Blackbreath
						encounterId = 9537
					},
					{
						-- Ribbly Screwspigot
						encounterId = 9543
					},
					{
						-- Plugger Spazzring
						encounterId = 9499
					},
					{
						-- Phalanx
						encounterId = 9502
					},
					{
						-- Ambassador Flamelash
						encounterId = 9156
					},
					{
						-- The Seven
						encounterId = 9034,
						npcIds = { 9034, 9035, 9036, 9037, 9038, 9039, 9040 }
					},
					{
						-- Magmus
						encounterId = 9938
					},
					{
						-- Emperor Thaurissan
						encounterId = 9019,
						npcIds = { 9019, 8929 }
					}
				}
			},
			{
				-- Sunken Temple
				instanceId = "SunkenTemple",
				encounters = {
					{
						-- Atal'alarion
						encounterId = 8580
					},
					{
						-- Zolo
						encounterId = 5712
					},
					{
						-- Gasher
						encounterId = 5713
					},
					{
						-- Loro
						encounterId = 5714
					},
					{
						-- Hukku
						encounterId = 5715
					},
					{
						-- Zul'Lor
						encounterId = 5716
					},
					{
						-- Mijan
						encounterId = 5717
					},
					{
						-- Jammal'an the Prophet
						encounterId = 5710,
						npcIds = { 5710, 5711 }
					},
					{
						-- Dreamscythe
						encounterId = 5721
					},
					{
						-- Weaver
						encounterId = 5720
					},
					{
						-- Morphaz
						encounterId = 5719
					},
					{
						-- Hazzas
						encounterId = 5722
					},
					{
						-- Shade of Eranikus
						encounterId = 5709
					},
					{
						-- Avatar of Hakkar
						encounterId = 8443
					}
				}
			},
			{
				-- Maraudon
				instanceId = "Maraudon",
				encounters = {
					{
						-- Noxxion
						encounterId = 13282
					},
					{
						-- Razorlash
						encounterId = 12258
					},
					{
						-- Lord Vyletongue
						encounterId = 12236
					},
					{
						-- Celebras the Cursed
						encounterId = 12225
					},
					{
						-- Landslide
						encounterId = 12203
					},
					{
						-- Tinkerer Gizlock
						encounterId = 13601
					},
					{
						-- Rotgrip
						encounterId = 13596
					},
					{
						-- Princess Theradras
						encounterId = 12201
					}
				}
			},
			{
				-- Zul'Farrak
				instanceId = "ZulFarrak",
				encounters = {
					{
						-- Antu'sul
						encounterId = 8127
					},
					{
						-- Theka the Martyr
						encounterId = 7272
					},
					{
						-- Witch Doctor Zum'rah
						encounterId = 7271
					},
					{
						-- Execution Event
						encounterId = 7275,
						npcIds = { 7275, 7796 }
					},
					{
						-- Sergeant Bly
						encounterId = 7604
					},
					{
						-- Hydromancer Velrath
						encounterId = 7795
					},
					{
						-- Gahz'rilla
						encounterId = 7273
					},
					{
						-- Chief Ukorz Sandscalp
						encounterId = 7267,
						npcIds = { 7267, 7797 }
					}
				}
			},
			{
				-- Uldaman
				instanceId = "Uldaman",
				encounters = {
					{
						-- Revelosh
						encounterId = 6910
					},
					{
						-- The Lost Dwarves
						encounterId = 6906,
						npcIds = { 6906, 6907, 6908 }
					},
					{
						-- Ironaya
						encounterId = 7228
					},
					{
						-- Obsidian Sentinel
						encounterId = 7023
					},
					{
						-- Ancient Stone Keeper
						encounterId = 7206
					},
					{
						-- Galgann Firehammer
						encounterId = 7291
					},
					{
						-- Grimlok
						encounterId = 4854
					},
					{
						-- Archaedas
						encounterId = 2748
					}
				
				}
			},
			{
				-- Scarlet Monastery
				instanceId = "ScarletMonastery",
				encounters = {
					{
						-- Interrogator Vishas
						encounterId = 3983
					},
					{
						-- Bloodmage Thalnos
						encounterId = 4543
					},
					{
						-- Houndmaster Loksey
						encounterId = 3974
					},
					{
						-- Arcanist Doan
						encounterId = 6487
					},
					{
						-- Herod
						encounterId = 3975
					},
					{
						-- High Inquisitor Fairbanks
						encounterId = 4542
					},
					{
						-- Scarlet Commander Mograine
						encounterId = 3976,
						npcIds = { 3976, 3977 }
					}
				}
			},
			{
				-- Razorfen Downs
				instanceId = "RazorfenDowns",
				encounters = {
					{
						-- Tuten'kash
						encounterId = 7355
					},
					{
						-- Plaguemaw the Rotting
						encounterId = 7356
					},
					{
						-- Mordresh Fire Eye
						encounterId = 7357
					},
					{
						-- Glutton
						encounterId = 8567
					},
					{
						-- Amnennar the Coldbringer
						encounterId = 7358
					}
				}
			},
			{
				-- Gnomeregan
				instanceId = "Gnomeregan",
				encounters = {
					{
						-- Grubbis
						encounterId = 7361
					},
					{
						-- Viscous Fallout
						encounterId = 7079
					},
					{
						-- Electrocutioner 6000
						encounterId = 6235
					},
					{
						-- Crowd Pummeler 9-60
						encounterId = 6229
					},
					{
						-- Dark Iron Ambassador
						encounterId = 6228
					},
					{
						-- Mekgineer Thermaplugg
						encounterId = 7800
					}
				}
			},
			{
				-- The Stockade
				instanceId = "TheStockade",
				encounters = {
					{
						-- Targorr the Dread
						encounterId = 1696
					},
					{
						-- Kam Deepfury
						encounterId = 1666
					},
					{
						-- Hamhock
						encounterId = 1717
					},
					{
						-- Bazil Thredd
						encounterId = 1716
					},
					{
						-- Dextren Ward
						encounterId = 1663
					}
				}
			},
			{
				-- Razorfen Kraul
				instanceId = "RazorfenKraul",
				encounters = {
					{
						-- Roogug
						encounterId = 6168
					},
					{
						-- Aggem Thorncurse
						encounterId = 4424
					},
					{
						-- Death Speaker Jargba
						encounterId = 4428
					},
					{
						-- Overlord Ramtusk
						encounterId = 4420
					},
					{
						-- Agathelos the Raging
						encounterId = 4422
					},
					{
						-- Charlga Razorflank
						encounterId = 4421
					}
				}
			},
			{
				-- Blackfathom Deeps
				instanceId = "BlackfathomDeeps",
				encounters = {
					{
						-- Ghamoo-ra
						encounterId = 4887
					},
					{
						-- Lady Sarevess
						encounterId = 4831
					},
					{
						-- Gelihast
						encounterId = 6243
					},
					{
						-- Lorgus Jett
						encounterId = 12902
					},
					{
						-- Baron Aquanis
						encounterId = 12876
					},
					{
						-- Old Serra'kis
						encounterId = 4830
					},
					{
						-- Twilight Lord Kelris
						encounterId = 4832
					},
					{
						-- Aku'mai
						encounterId = 4829
					}
				}
			},
			{
				-- Shadowfang Keep
				instanceId = "ShadowfangKeep",
				encounters = {
					{
						-- Rethilgore
						encounterId = 3914
					},
					{
						-- Razorclaw the Butcher
						encounterId = 3886
					},
					{
						-- Baron Silverlaine
						encounterId = 3887
					},
					{
						-- Commander Springvale
						encounterId = 4278
					},
					{
						-- Odo the Blindwatcher
						encounterId = 4279
					},
					{
						-- Fenrus the Devourer
						encounterId = 4274
					},
					{
						-- Wolf Master Nandos
						encounterId = 3927
					},
					{
						-- Archmag Arugal
						encounterId = 4275
					}
				}
			},
			{
				-- Wailing Caverns
				instanceId = "WailingCaverns",
				encounters = {
					{
						-- Lady Anacondra
						encounterId = 3671
					},
					{
						-- Lord Cobrahn
						encounterId = 3669
					},
					{
						-- Kresh
						encounterId = 3653
					},
					{
						-- Lord Pythas
						encounterId = 3670
					},
					{
						-- Skum
						encounterId = 3674
					},
					{
						-- Lord Serpentis
						encounterId = 3673
					},
					{
						-- Verdan the Everliving
						encounterId = 5775
					},
					{
						-- Mutanus the Devourer
						encounterId = 3654
					}
				}
			},
			{
				-- The Deadmines
				instanceId = "TheDeadmines",
				npcIds = {
					1729, 598, 634, 657, 1732, 4416, 4417, 1725,
					4418, 1731, 622, 641
				},
				encounters = {
					{
						-- Rhahk'Zor
						encounterId = 644
					},
					{
						-- Sneed
						encounterId = 643,
						npcIds = { 643, 642 }
					},
					{
						-- Gilnid
						encounterId = 1763
					},
					{
						-- Mr. Smite
						encounterId = 646
					},
					{
						-- Cookie
						encounterId = 645
					},
					{
						-- Captain Greenskin
						encounterId = 647
					},
					{
						-- Edwin VanCleef
						encounterId = 639
					}
				}
			},
			{
				-- Ragefire Chasm
				instanceId = "RagefireChasm",
				encounters = {
					{
						-- Oggleflint
						encounterId = 11517
					},
					{
						-- Taragaman the Hungerer
						encounterId = 11520
					},
					{
						-- Jergosh the Invoker
						encounterId = 11518
					},
					{
						-- Bazzalan
						encounterId = 11519
					}
				}
			}
		}
	}
}

-- Fixup
for _, instanceSet in ipairs(BOSS_NOTES_ENCOUNTERS) do
	instanceSet.name = L[instanceSet.instanceSetId]
	for _, instance in ipairs(instanceSet.instances) do
		instance.name = L["instance:" .. instance.instanceId]
		if not instance.npcIds then
			instance.npcIds = { }
		end
		for _, encounter in ipairs(instance.encounters) do
			encounter.name = L["encounter:" .. encounter.encounterId]
			if not encounter.npcIds then
				encounter.npcIds = { encounter.encounterId }
			end
		end
	end
end